ThreadTriggers

Struct ThreadTriggers 

#[non_exhaustive]
pub struct ThreadTriggers { pub on_create: bool, pub on_resume: bool, pub on_yield: bool, }
Controls which thread lifecycle events trigger the callback.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
on_create: bool

Trigger the callback when a new thread is created.

on_resume: bool

Trigger the callback before a thread is resumed (via Thread::resume).

on_yield: bool

Trigger the callback after a thread yields.

Implementations

Source

impl ThreadTriggers

pub const ON_CREATE: Self

An instance of ThreadTriggers with on_create trigger set.

pub const ON_RESUME: Self

An instance of ThreadTriggers with on_resume trigger set.

pub const ON_YIELD: Self

An instance of ThreadTriggers with on_yield trigger set.

pub const fn new() -> Self

Returns a new instance of ThreadTriggers with all triggers disabled.

pub const fn on_create(self) -> Self

Returns an instance of ThreadTriggers with on_create trigger set.

pub const fn on_resume(self) -> Self

Returns an instance of ThreadTriggers with on_resume trigger set.

pub const fn on_yield(self) -> Self

Returns an instance of ThreadTriggers with on_yield trigger set.